@@ -385,11 +385,10 @@ class Dropdown(urwid.PopUpLauncher):
 
         if isinstance(self.items, list):
             if len(self.items):
-                if isinstance(self.items[0], tuple):
-                    self._items = AttrDict(self.items)
-                else:
-                    logger.debug(self.items)
-                    self._items = AttrDict(( (item, n) for n, item in enumerate(self.items)))
+                self._items = AttrDict(
+                    item if isinstance(item, tuple) else (item, n)
+                    for n, item in enumerate(self.items)
+                )
             else:
                 self._items = AttrDict()
         else:
@@ -448,7 +447,7 @@ class Dropdown(urwid.PopUpLauncher):
             except StopIteration:
                 try:
                     self.select_value(self.default)
-                except StopIteration:
+                except ValueError:
                     self.focus_position = 0
 
         if len(self):
@@ -601,23 +600,6 @@ class Dropdown(urwid.PopUpLauncher):
     def selection(self):
         return self.pop_up.selection
 
-    def select_label(self, label, case_sensitive=False):
-
-        old_value = self.value
-
-        f = lambda x: x
-        if not case_sensitive:
-            f = lambda x: x.lower()
-
-        index = next(itertools.dropwhile(
-                lambda x: f(x[1]) != f(label),
-                enumerate((self._items.keys())
-            )
-        ))[0]
-        self.focus_position = index
-
-
-
     @property
     def items(self):
         return self._items
@@ -626,7 +608,6 @@ class Dropdown(urwid.PopUpLauncher):
     def selection(self):
         return self.pop_up.selection
 
-
     def select_label(self, label, case_sensitive=False):
 
         old_value = self.value
@@ -641,19 +622,21 @@ class Dropdown(urwid.PopUpLauncher):
                     enumerate((self._items.keys())
                 )
             ))[0]
-        except StopIteration:
+        except (StopIteration, IndexError):
             raise ValueError
         self.focus_position = index
 
-
-
     def select_value(self, value):
 
-        index = next(itertools.dropwhile(
-                lambda x: x[1] != value,
-                enumerate((self._items.values())
-            )
-        ))[0]
+        try:
+            index = next(
+                itertools.dropwhile(
+                    lambda x: x[1] != value,
+                enumerate((self._items.values()))
+                )
+            )[0]
+        except (StopIteration, IndexError):
+            raise ValueError
         self.focus_position = index
 
 
