@@ -4,6 +4,7 @@ logger = logging.getLogger(__name__.split(".")[0])
 
 import urwid
 from urwid_utils.palette import *
+from .scroll import ScrollBar
 
 class ListBoxScrollBar(urwid.WidgetWrap):
 
@@ -17,6 +18,7 @@ class ListBoxScrollBar(urwid.WidgetWrap):
         scroll_marker_height = 1
         del self.pile.contents[:]
         if (len(self.parent.body)
+            and self.parent.row_count
             and self.parent.focus is not None
             and self.parent.row_count > height):
             scroll_position = int(
@@ -24,7 +26,7 @@ class ListBoxScrollBar(urwid.WidgetWrap):
             )
             scroll_marker_height = max( height * (height / self.parent.row_count ), 1)
         else:
-            scroll_position = -1
+            scroll_position = 0
 
         pos_marker = urwid.AttrMap(urwid.Text(" "),
                                    {None: "scroll_pos"}
@@ -56,7 +58,7 @@ class ListBoxScrollBar(urwid.WidgetWrap):
                     marker = begin_marker
                 elif i+1 == height and self.parent.row_count == self.parent.focus_position+1:
                     marker = end_marker
-                elif len(self.parent.body) == self.parent.focus_position+1 and i == scroll_position + scroll_marker_height//2:
+                elif self.parent.focus_position is not None and len(self.parent.body) == self.parent.focus_position+1 and i == scroll_position + scroll_marker_height//2:
                     marker = down_marker
                 else:
                     marker = pos_marker
@@ -76,35 +78,41 @@ class ListBoxScrollBar(urwid.WidgetWrap):
         # FIXME: mouse click/drag
         return False
 
-
 class ScrollingListBox(urwid.WidgetWrap):
 
     signals = ["select",
                "drag_start", "drag_continue", "drag_stop",
                "load_more"]
 
+    scrollbar_class = ScrollBar
+
     def __init__(self, body,
                  infinite = False,
                  with_scrollbar=False,
-                 scroll_rows=None,
-                 row_count_fn = None):
+                 row_count_fn = None,
+                 thumb_char=None,
+                 trough_char=None,
+                 thumb_indicator_top=None,
+                 thumb_indicator_bottom=None):
 
         self.infinite = infinite
         self.with_scrollbar = with_scrollbar
-        self.scroll_rows = scroll_rows
         self.row_count_fn = row_count_fn
 
+        self._width = None
+        self._height = 0
+        self._rows_max = None
+
         self.mouse_state = 0
         self.drag_from = None
         self.drag_last = None
         self.drag_to = None
         self.load_more = False
-        self.height = 0
         self.page = 0
 
         self.queued_keypress = None
+        w = self.listbox = urwid.ListBox(body)
 
-        self.listbox = urwid.ListBox(body)
         self.columns = urwid.Columns([
             ('weight', 1, self.listbox)
         ])
@@ -114,6 +122,15 @@ class ScrollingListBox(urwid.WidgetWrap):
                 (self.scroll_bar, self.columns.options("given", 1))
             )
         super(ScrollingListBox, self).__init__(self.columns)
+        urwid.connect_signal(self.body, "modified", self.on_modified)
+
+    def on_modified(self):
+        if self.with_scrollbar and len(self.body):
+            self.scroll_bar.update(self.size)
+
+    def rows_max(self, size, focus=False):
+        return urwid.ListBox.rows_max(self, size, focus)
+
 
     @classmethod
     def get_palette_entries(cls):
@@ -154,21 +171,21 @@ class ScrollingListBox(urwid.WidgetWrap):
     def mouse_event(self, size, event, button, col, row, focus):
 
         SCROLL_WHEEL_HEIGHT_RATIO = 0.5
-        if row < 0 or row >= self.height:
+        if row < 0 or row >= self._height or not len(self.listbox.body):
             return
         if event == 'mouse press':
             if button == 1:
                 self.mouse_state = 1
                 self.drag_from = self.drag_last = (col, row)
             elif button == 4:
-                pos = self.listbox.focus_position - int(self.height * SCROLL_WHEEL_HEIGHT_RATIO)
+                pos = self.listbox.focus_position - int(self._height * SCROLL_WHEEL_HEIGHT_RATIO)
                 if pos < 0:
                     pos = 0
                 self.listbox.focus_position = pos
                 self.listbox.make_cursor_visible(size)
                 self._invalidate()
             elif button == 5:
-                pos = self.listbox.focus_position + int(self.height * SCROLL_WHEEL_HEIGHT_RATIO)
+                pos = self.listbox.focus_position + int(self._height * SCROLL_WHEEL_HEIGHT_RATIO)
                 if pos > len(self.listbox.body) - 1:
                     if self.infinite:
                         self.load_more = True
@@ -225,8 +242,8 @@ class ScrollingListBox(urwid.WidgetWrap):
         elif command == "activate":
             urwid.signals.emit_signal(self, "select", self, self.selection)
 
-        else:
-            return super(ScrollingListBox, self).keypress(size, key)
+        # else:
+        return super(ScrollingListBox, self).keypress(size, key)
 
     @property
     def selection(self):
@@ -234,10 +251,22 @@ class ScrollingListBox(urwid.WidgetWrap):
         if len(self.body):
             return self.body[self.focus_position]
 
+    @property
+    def size(self):
+        return (self._width, self._height)
 
     def render(self, size, focus=False):
 
-        maxcol, maxrow = size
+        maxcol = size[0]
+        self._width = maxcol
+        if len(size) > 1:
+            maxrow = size[1]
+            modified = self._height == 0
+            self._height = maxrow
+            if modified:
+                self.on_modified()
+        else:
+            self._height = 0
 
         # print
         # print
@@ -251,27 +280,23 @@ class ScrollingListBox(urwid.WidgetWrap):
             self.load_more = False
             self.page += 1
             # old_len = len(self.body)
-            urwid.signals.emit_signal(
-                self, "load_more")
             try:
                 focus = self.focus_position
             except IndexError:
                 focus = None
+            urwid.signals.emit_signal(
+                self, "load_more", focus)
             if (self.queued_keypress
-                and focus
-                and focus < len(self.body)
+                and focus is not None
+                # and focus < len(self.body)-1
             ):
-                # logger.info("send queued keypress")
+                # logger.info(f"send queued keypress: {focus}, {len(self.body)}")
                 self.keypress(size, self.queued_keypress)
             self.queued_keypress = None
             # self.listbox._invalidate()
             # self._invalidate()
 
-        if self.with_scrollbar and len(self.body):
-            self.scroll_bar.update(size)
-
-        self.height = maxrow
-        return super(ScrollingListBox, self).render( (maxcol, maxrow), focus)
+        return super(ScrollingListBox, self).render(size, focus)
 
 
     def disable(self):
@@ -292,8 +317,10 @@ class ScrollingListBox(urwid.WidgetWrap):
     def focus_position(self):
         if not len(self.listbox.body):
             raise IndexError
-        if len(self.listbox.body):
+        try:
             return self.listbox.focus_position
+        except IndexError:
+            pass
         return None
 
     @focus_position.setter
@@ -304,7 +331,7 @@ class ScrollingListBox(urwid.WidgetWrap):
         self.listbox._invalidate()
 
     def __getattr__(self, attr):
-        if attr in ["ends_visible", "set_focus", "set_focus_valign", "body", "focus"]:
+        if attr in ["ends_visible", "focus_position", "set_focus", "set_focus_valign", "body", "focus"]:
             return getattr(self.listbox, attr)
         # elif attr == "body":
         #     return self.walker
